# LicensedProductPriceBreakdown

A breakdown of prices for a product for a given currency. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**currency** | **str** | The currency in which the prices are charged. | 
**prices** | [**[LicensedProductPrice]**](LicensedProductPrice.md) | The prices for this product. This is a list of prices, for each thing we might charge for.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


